//
//  SODWindowController.m
//  ViewSwappingDemo
//
//  Created by Nate Chandler on 10/15/12.
//  Use freely.
//

#import "SODWindowController.h"
#import "SODCoffeeViewController.h"
#import "SODTeaViewController.h"
#import "SODJavaViewController.h"
#import "SODMeViewController.h"

@interface SODWindowController ()
@property (nonatomic, strong, readwrite) IBOutlet NSBox *box;
@property (nonatomic, strong, readwrite) NSArray *viewControllers;
@property (nonatomic, strong, readwrite) NSMutableArray *panesBehind;
@property (nonatomic, strong, readwrite) NSMutableArray *panesBefore;
- (IBAction)showPane:(id)sender;
@end

@implementation SODWindowController

- (id)init
{
	self = [super initWithWindowNibName:@"SODWindowController"];
	if (self) {
		NSMutableArray *mutableViewControllers = [NSMutableArray array];
        [mutableViewControllers addObject:[[SODCoffeeViewController alloc] init]];
        [mutableViewControllers addObject:[[SODTeaViewController alloc] init]];
        [mutableViewControllers addObject:[[SODJavaViewController alloc] init]];
        [mutableViewControllers addObject:[[SODMeViewController alloc] init]];
        self.viewControllers = [mutableViewControllers copy];
		
		self.panesBehind = [NSMutableArray array];
		self.panesBefore = [NSMutableArray array];
	}
	return self;    
}

- (void)windowDidLoad
{
    [super windowDidLoad];
    
	[self showPaneAtIndex:0];
}

- (void)showPane:(NSButton *)sender
{
	[self showPaneAtIndex:sender.tag];
	[self.panesBefore removeAllObjects];
}

- (void)showPaneAtIndex:(NSInteger)index
{
	NSViewController *viewController = (NSViewController *)self.viewControllers[(NSUInteger)index];
	[self.box setContentView:viewController.view];
	[self.panesBehind addObject:[NSNumber numberWithInteger:index]];
}

- (BOOL)canGoBack
{
	return self.panesBehind.count > 0;
}

- (void)goBack
{
	if (self.canGoBack) {
		NSNumber *presentPane = self.panesBehind.lastObject;
		[self.panesBehind removeLastObject];
		[self.panesBefore insertObject:presentPane atIndex:0];
		NSNumber *previousPane = self.panesBehind.lastObject;
		[self.panesBehind removeLastObject];
		[self showPaneAtIndex:previousPane.integerValue];
	}
}

- (BOOL)canGoForward
{
	return self.panesBefore.count > 0;
}

- (void)goForward
{
	if (self.canGoForward) {
		NSNumber *nextPane = [self.panesBefore objectAtIndex:0];
		[self.panesBefore removeObjectAtIndex:0];
		[self showPaneAtIndex:nextPane.integerValue];
	}
}

@end
